var NAVTREEINDEX1 =
{
"encoder_guide.html#architecture_enc_gf_length":[8,7,2],
"encoder_guide.html#architecture_enc_gf_structure":[8,7,3],
"encoder_guide.html#architecture_enc_inter_modes":[8,11],
"encoder_guide.html#architecture_enc_intra_modes":[8,10],
"encoder_guide.html#architecture_enc_kf_groups":[8,7,4],
"encoder_guide.html#architecture_enc_partitions":[8,9],
"encoder_guide.html#architecture_enc_rate_ctrl":[8,6],
"encoder_guide.html#architecture_enc_rate_ctrl_data":[8,6,0],
"encoder_guide.html#architecture_enc_rate_ctrl_options":[8,6,1],
"encoder_guide.html#architecture_enc_rc_loop":[8,6,3],
"encoder_guide.html#architecture_enc_speed_quality":[8,4],
"encoder_guide.html#architecture_enc_src_proc":[8,5],
"encoder_guide.html#architecture_enc_tpl":[8,8],
"encoder_guide.html#architecture_enc_tpl_algoritms":[8,8,1],
"encoder_guide.html#architecture_enc_tpl_config":[8,8,0],
"encoder_guide.html#architecture_enc_tpl_keyfun":[8,8,2],
"encoder_guide.html#architecture_enc_tx_search":[8,12],
"encoder_guide.html#architecture_enc_use_cases":[8,3],
"encoder_guide.html#architecture_enc_vbr":[8,6,2],
"encoder_guide.html#architecture_entropy":[8,14],
"encoder_guide.html#architecture_entropy_aritmetic":[8,14,0],
"encoder_guide.html#architecture_entropy_coef":[8,14,1],
"encoder_guide.html#architecture_entropy_coef_coding":[8,14,1,0,1],
"encoder_guide.html#architecture_entropy_coef_context":[8,14,1,0,2],
"encoder_guide.html#architecture_entropy_coef_cost":[8,14,1,1,0],
"encoder_guide.html#architecture_entropy_coef_opt":[8,14,1,1,1],
"encoder_guide.html#architecture_entropy_coef_prepare":[8,14,1,0,0],
"encoder_guide.html#architecture_entropy_coef_rd":[8,14,1,1],
"encoder_guide.html#architecture_entropy_coef_what":[8,14,1,0],
"encoder_guide.html#architecture_gencodecs":[8,0,0],
"encoder_guide.html#architecture_introduction":[8,0],
"encoder_guide.html#architecture_post_enc_filt":[8,13],
"encoder_guide.html#architecture_simd":[8,15],
"encodetxb_8h_source.html":[14,0,2,2,5],
"enums_8h.html":[14,0,2,0,4],
"enums_8h.html#ac8a22acdb7400608ded8cc8d83187acf":[14,0,2,0,4,0],
"enums_8h.html#ac8a22acdb7400608ded8cc8d83187acfa1937ae1cdacb6966fadd207ab57d61d5":[14,0,2,0,4,0,0],
"enums_8h.html#ac8a22acdb7400608ded8cc8d83187acfa6ab780013b48741f824c2357aa5c9c0a":[14,0,2,0,4,0,4],
"enums_8h.html#ac8a22acdb7400608ded8cc8d83187acfa8dc0118ab1758e185d3c5e8924f5e449":[14,0,2,0,4,0,3],
"enums_8h.html#ac8a22acdb7400608ded8cc8d83187acfac01ffda44bc889f506f7b3f5f8e9ebe3":[14,0,2,0,4,0,5],
"enums_8h.html#ac8a22acdb7400608ded8cc8d83187acfac2c86f008a1cafeaeb362b8673687780":[14,0,2,0,4,0,2],
"enums_8h.html#ac8a22acdb7400608ded8cc8d83187acfac64b3c61c2aa8431f7d686aba5d1ee12":[14,0,2,0,4,0,1],
"enums_8h_source.html":[14,0,2,0,4],
"example_aom_cx_set_ref.html":[9,9],
"example_aomdec.html":[9,14],
"example_aomenc.html":[9,15],
"example_decode_to_md5.html":[9,0],
"example_decode_with_drops.html":[9,1],
"example_lightfield_bitstream_parsing.html":[9,13],
"example_lightfield_decoder.html":[9,12],
"example_lightfield_encoder.html":[9,10],
"example_lightfield_tile_list_decoder.html":[9,11],
"example_lossless_encoder.html":[9,3],
"example_scalable_encoder.html":[9,7],
"example_set_maps.html":[9,4],
"example_simple_decoder.html":[9,2],
"example_simple_encoder.html":[9,5],
"example_svc_encoder_rtc.html":[9,8],
"example_twopass_encoder.html":[9,6],
"files.html":[14,0],
"firstpass_8h_source.html":[14,0,2,2,6],
"functions.html":[13,1,0],
"functions.html":[13,1,0,0],
"functions_b.html":[13,1,0,1],
"functions_c.html":[13,1,0,2],
"functions_d.html":[13,1,0,3],
"functions_e.html":[13,1,0,4],
"functions_f.html":[13,1,0,5],
"functions_g.html":[13,1,0,6],
"functions_h.html":[13,1,0,7],
"functions_i.html":[13,1,0,8],
"functions_j.html":[13,1,0,9],
"functions_k.html":[13,1,0,10],
"functions_l.html":[13,1,0,11],
"functions_m.html":[13,1,0,12],
"functions_n.html":[13,1,0,13],
"functions_o.html":[13,1,0,14],
"functions_p.html":[13,1,0,15],
"functions_q.html":[13,1,0,16],
"functions_r.html":[13,1,0,17],
"functions_s.html":[13,1,0,18],
"functions_t.html":[13,1,0,19],
"functions_u.html":[13,1,0,20],
"functions_v.html":[13,1,0,21],
"functions_vars.html":[13,1,1],
"functions_vars.html":[13,1,1,0],
"functions_vars_b.html":[13,1,1,1],
"functions_vars_c.html":[13,1,1,2],
"functions_vars_d.html":[13,1,1,3],
"functions_vars_e.html":[13,1,1,4],
"functions_vars_f.html":[13,1,1,5],
"functions_vars_g.html":[13,1,1,6],
"functions_vars_h.html":[13,1,1,7],
"functions_vars_i.html":[13,1,1,8],
"functions_vars_j.html":[13,1,1,9],
"functions_vars_k.html":[13,1,1,10],
"functions_vars_l.html":[13,1,1,11],
"functions_vars_m.html":[13,1,1,12],
"functions_vars_n.html":[13,1,1,13],
"functions_vars_o.html":[13,1,1,14],
"functions_vars_p.html":[13,1,1,15],
"functions_vars_q.html":[13,1,1,16],
"functions_vars_r.html":[13,1,1,17],
"functions_vars_s.html":[13,1,1,18],
"functions_vars_t.html":[13,1,1,19],
"functions_vars_u.html":[13,1,1,20],
"functions_vars_v.html":[13,1,1,21],
"functions_vars_w.html":[13,1,1,22],
"functions_vars_x.html":[13,1,1,23],
"functions_vars_y.html":[13,1,1,24],
"functions_vars_z.html":[13,1,1,25],
"functions_w.html":[13,1,0,22],
"functions_x.html":[13,1,0,23],
"functions_y.html":[13,1,0,24],
"functions_z.html":[13,1,0,25],
"globals.html":[14,1,0],
"globals.html":[14,1,0,0],
"globals_c.html":[14,1,0,1],
"globals_defs.html":[14,1,6],
"globals_e.html":[14,1,0,2],
"globals_enum.html":[14,1,4],
"globals_eval.html":[14,1,5],
"globals_eval.html":[14,1,5,0],
"globals_eval_c.html":[14,1,5,1],
"globals_eval_e.html":[14,1,5,2],
"globals_eval_i.html":[14,1,5,3],
"globals_eval_l.html":[14,1,5,4],
"globals_eval_n.html":[14,1,5,5],
"globals_eval_p.html":[14,1,5,6],
"globals_eval_q.html":[14,1,5,7],
"globals_eval_r.html":[14,1,5,8],
"globals_eval_s.html":[14,1,5,9],
"globals_eval_t.html":[14,1,5,10],
"globals_f.html":[14,1,0,3],
"globals_func.html":[14,1,1],
"globals_h.html":[14,1,0,4],
"globals_i.html":[14,1,0,5],
"globals_l.html":[14,1,0,6],
"globals_m.html":[14,1,0,7],
"globals_n.html":[14,1,0,8],
"globals_o.html":[14,1,0,9],
"globals_p.html":[14,1,0,10],
"globals_q.html":[14,1,0,11],
"globals_r.html":[14,1,0,12],
"globals_s.html":[14,1,0,13],
"globals_t.html":[14,1,0,14],
"globals_type.html":[14,1,3],
"globals_vars.html":[14,1,2],
"gop__structure_8h_source.html":[14,0,2,2,7],
"group__SVC.html":[12,2,10],
"group__SVC.html#ga2794fc40366548624954f66b967e8632":[12,2,10,13],
"group__SVC.html#ga5dd7109b02e80cc7d843c94ae7c47e58":[12,2,10,6],
"group__SVC.html#ga5f92b5ac15dcde4004d6f35586d4773b":[12,2,10,11],
"group__SVC.html#ga653e04e3b1fe8ab04c663673e45f3a16":[12,2,10,8],
"group__SVC.html#ga70a315e24d83741c8d182397800f4e94":[12,2,10,7],
"group__SVC.html#ga814c2aa58e2ca79dedfd0d9872316586":[12,2,10,9],
"group__SVC.html#ga851225444c51cbd64e23e6aac4086d46":[12,2,10,4],
"group__SVC.html#ga8fd7af0cfb7a8a1031a11e391ce56b7b":[12,2,10,3],
"group__SVC.html#gab71c263f4405fb913e3936da9bbd4f0c":[12,2,10,2],
"group__SVC.html#gac3591bba20df432db53410504e3cbf42":[12,2,10,10],
"group__SVC.html#gaf1d134bde262a8dde127bdd6b97a9d24":[12,2,10,12],
"group__SVC.html#gaf592ef7e4ef34c2b94806e5c9d65b19c":[12,2,10,14],
"group__SVC.html#gaf68d8ebe20cd4f5d244e1cfd57517971":[12,2,10,5],
"group__aom.html":[12,1,0],
"group__aom.html#ga48948a6e11f6b314f66a3387aee9d5df":[12,1,0,4],
"group__aom.html#ga9421a1fa78c0d9587ae5aa6c1cb3d659":[12,1,0,5],
"group__aom.html#gga9421a1fa78c0d9587ae5aa6c1cb3d659a155fc3906e61acda15149129136ab8cd":[12,1,0,5,5],
"group__aom.html#gga9421a1fa78c0d9587ae5aa6c1cb3d659a410c706a34f5295996658cc5044a700f":[12,1,0,5,3],
"group__aom.html#gga9421a1fa78c0d9587ae5aa6c1cb3d659a4b8bcdaae4f4ff2e78d2e9d53090e13b":[12,1,0,5,0],
"group__aom.html#gga9421a1fa78c0d9587ae5aa6c1cb3d659a51ad4467b4dc318406cceb257e2daa41":[12,1,0,5,1],
"group__aom.html#gga9421a1fa78c0d9587ae5aa6c1cb3d659ae41763622ee33cd99e23ca8f78a3f8fa":[12,1,0,5,4],
"group__aom.html#gga9421a1fa78c0d9587ae5aa6c1cb3d659af5c56c3dbccf31fca7621e8327ba7354":[12,1,0,5,2],
"group__aom__decoder.html":[12,1,0,1],
"group__aom__decoder.html#ga108f7f2ff3f450ad1fb574cecd15fd72":[12,1,0,1,18],
"group__aom__decoder.html#ga1b37b4b76004e5a2776c2e2f16b052cd":[12,1,0,1,12],
"group__aom__decoder.html#ga3747f3c9af0ff0dfc68196b00efd7771":[12,1,0,1,22],
"group__aom__decoder.html#ga3865fd4b3192489baa9a5c3632ebe97b":[12,1,0,1,20],
"group__aom__decoder.html#ga4e755ba2db79154311994183ad9e4b28":[12,1,0,1,11],
"group__aom__decoder.html#ga535cbd802e32dbe437bda8e8c30614c9":[12,1,0,1,21],
"group__aom__decoder.html#ga6c42dc93877dd6ffbf24e7a3560de6cc":[12,1,0,1,16],
"group__aom__decoder.html#ga8b5b92c20edb29173182b5e30edd55d2":[12,1,0,1,10],
"group__aom__decoder.html#gaa7df1f59e745188fcd02dbdd8018893b":[12,1,0,1,9],
"group__aom__decoder.html#gab05eb9e558015080eb8ec694c984fff6":[12,1,0,1,17],
"group__aom__decoder.html#gac65dc901d702e0094dc72f04e7448913":[12,1,0,1,15],
"group__aom__decoder.html#gace99b38e5d18359cfba3e0d769511ea9":[12,1,0,1,13],
"group__aom__decoder.html#gaf33ade89af86db481078ef1c405bbee8":[12,1,0,1,19],
"group__aom__decoder.html#gafaa2418e0318a2490ed892695b41e374":[12,1,0,1,14],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba03f15fd9a3044ca1a1707e12b6a4588b":[12,1,0,1,20,2],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba0795d8084ae8c78528c01587198df9e2":[12,1,0,1,20,15],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba159ddb748cb69956226b7c13e3890ff6":[12,1,0,1,20,1],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba175c454a7adf2d3927a0e979b4a2b07b":[12,1,0,1,20,3],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba17fa09c9ce1ae4a68eae21efd219418b":[12,1,0,1,20,25],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba1c3836ef68ecfb7f92b198b454fec4d7":[12,1,0,1,20,29],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba1fb269c5c5913d9995b6c35d28e2a788":[12,1,0,1,20,21],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba242d7dba47ef646f51f9795e2fa92f91":[12,1,0,1,20,8],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba27d139da59a2c76783d7ea0918c95a9a":[12,1,0,1,20,36],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba294a62ae333661906ff55b04086675c7":[12,1,0,1,20,32],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba306a4eb7c886f509a94ea3054794c288":[12,1,0,1,20,33],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba3fae4dd7641d3f53723d9a6672758e0c":[12,1,0,1,20,37],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba41756871003a7d391f00a11673c38769":[12,1,0,1,20,28],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba441d4d82094aced6570face51368ca23":[12,1,0,1,20,35],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba45b658bd6518cfd30c56b13e98ab168a":[12,1,0,1,20,11],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba4784af3a10d73a36f739cb1c99caf876":[12,1,0,1,20,20],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba4d9799d9e520785870b8d1f73a19c3c4":[12,1,0,1,20,7],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba592a5d1390204d743ddfe7bfe8ef177c":[12,1,0,1,20,4],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba8d51f96b8877b665225f5cfaa73ded8e":[12,1,0,1,20,23],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97ba9bc290107ed0adac808a674b09741ba7":[12,1,0,1,20,30],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97baa8b955fc5a2f6e33c6dad858d7c15f67":[12,1,0,1,20,22],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97baa984acc8b42df9c7d18fc3556a14fd29":[12,1,0,1,20,13],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97baad96ac15f7a0999d74e9a6b281563104":[12,1,0,1,20,38],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97bab41a1ef60d33d804b8aabbce0b5f706f":[12,1,0,1,20,27],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97bab7332818193596356a580c83ecb12a66":[12,1,0,1,20,12],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97babab96509cdce01ed1cf027185da4d874":[12,1,0,1,20,0],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97babb0f1c97c6092ebed96ca9800e05157e":[12,1,0,1,20,9],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97bac056b4cf80427fd05e3c4c9fc46edb78":[12,1,0,1,20,14],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97bac19ffcb187b1e1b5eee18499a97f69d2":[12,1,0,1,20,10],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97bac4e9db108f3257dece09f167ec6aac5f":[12,1,0,1,20,31],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97bacd7229e5fb766670fe995739931c2ee3":[12,1,0,1,20,6],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97bace55b4f6d152f2f0d29f70ab918cba4f":[12,1,0,1,20,5],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97bad1036f9d92ad1f0afa51e33150354585":[12,1,0,1,20,26],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97bad35d0b5df17dc5465d62b602d62458d1":[12,1,0,1,20,34],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97badf1e96275f692bc97ddb4ce2fbdb456e":[12,1,0,1,20,17],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97badfbe6c1ebe4039bfef4d2cfd98755add":[12,1,0,1,20,18],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97bae02fd57774db8c30e49b083fa51b6236":[12,1,0,1,20,24],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97baed16ed4514ea1bd2847e607ca880b246":[12,1,0,1,20,16],
"group__aom__decoder.html#gga3865fd4b3192489baa9a5c3632ebe97baffdaca91296725bd16142a33f3cc6522":[12,1,0,1,20,19],
"group__aom__encoder.html":[12,1,0,0],
"group__aom__encoder.html#ga0081baafcdae3ae12228f2083954ed6b":[12,1,0,0,88],
"group__aom__encoder.html#ga00f4961195d6d1d53c045d9675bb4d78":[12,1,0,0,55],
"group__aom__encoder.html#ga0713a9137d099e441bd6b7ed10be1b0d":[12,1,0,0,57],
"group__aom__encoder.html#ga0f19205f8fb08e9d9aa49403428ff33b":[12,1,0,0,45],
"group__aom__encoder.html#ga1041d05f74205cf3cfbe4d05a1f99345":[12,1,0,0,87],
"group__aom__encoder.html#ga18350b1c0642494e2b1a970104b2e8b9":[12,1,0,0,90],
"group__aom__encoder.html#ga1a11077df0999ffba72a6fbfc8fe3331":[12,1,0,0,65],
"group__aom__encoder.html#ga23f13860556f8879c2cef2565b8182a8":[12,1,0,0,30],
"group__aom__encoder.html#ga241e62c4cf0d5f31f56e6be63df8e566":[12,1,0,0,80],
"group__aom__encoder.html#ga28cc21cd9c9fc1f02818e90772a0baf6":[12,1,0,0,26],
"group__aom__encoder.html#ga29427094de00e8d1883207afcc28b22c":[12,1,0,0,24],
"group__aom__encoder.html#ga2a1791d26fca39303154f0f9ece3e295":[12,1,0,0,83],
"group__aom__encoder.html#ga2c864d073d251c0ed7fe8d2b71c26417":[12,1,0,0,68],
"group__aom__encoder.html#ga2d4ad2535544500d48ac6ce6605cdf0c":[12,1,0,0,61],
"group__aom__encoder.html#ga31943c4d9e34f90a0691949109c224fd":[12,1,0,0,42],
"group__aom__encoder.html#ga3589babe0100b5bf7dc7167675014608":[12,1,0,0,47],
"group__aom__encoder.html#ga424f998c99e4a5584b60a41383af8dbe":[12,1,0,0,76],
"group__aom__encoder.html#ga45f71361ba7598dbb347d6f8de8f37b6":[12,1,0,0,53],
"group__aom__encoder.html#ga469b4cf5ff76cb30de951e129c25a786":[12,1,0,0,40],
"group__aom__encoder.html#ga4af3be5d269421964fc8b3e8681121dd":[12,1,0,0,64],
"group__aom__encoder.html#ga4b28cbe3036a6f1c5753fa461facc192":[12,1,0,0,81],
"group__aom__encoder.html#ga50c2560ca6670298cfc614ecae96a391":[12,1,0,0,32],
"group__aom__encoder.html#ga58817629f5270c0db0851e354cd6e57c":[12,1,0,0,46]
};
